@@ -2,8 +2,8 @@
 
 rm -rf out_* *_release-*
 
-python get_dataset.py
-
+morphology_workflows Initialize --source-database NeuroMorpho
+morphology_workflows Fetch
 morphology_workflows Curate
 morphology_workflows Annotate
 morphology_workflows Repair
