@@ -26,13 +26,18 @@ from neuror.zero_diameter_fixer import fix_zero_diameters as _fix_zero_diameters
 from scipy.spatial import KDTree
 from tqdm import tqdm
 
+from morphology_workflows import MorphologyWorkflowsError
 from morphology_workflows.marker_helper import MarkerSet
-from morphology_workflows.utils import disable_loggers
+from morphology_workflows.utils import silent_loggers
 
 L = logging.getLogger(__name__)
 matplotlib.use("Agg")
 
 
+class RepairError(MorphologyWorkflowsError):
+    """Exception for Repair step."""
+
+
 def fix_zero_diameters(row, data_dir):
     """Assign mtype to morphologies."""
     neuron = Morphology(row.morph_path)
@@ -55,7 +60,7 @@ def _unravel_leaves(leaves, mapping):
     distances, indices = t.query(leaves)
     not_matching_leaves = np.where(distances > 1e-3)[0]
     if not_matching_leaves.size:
-        raise Exception(
+        raise RepairError(
             f"Cannot find the following leaves in the mapping:\n{leaves[not_matching_leaves]}"
         )
     return mapping.iloc[indices][["x1", "y1", "z1"]].values
@@ -153,9 +158,9 @@ def plot_repair(row, data_dir, with_plotly=True):
         if markers is not None:
             points = markers.markers[0].data.T[[0, 2]]
 
-        with disable_loggers(
-            "matplotlib.font_manager", "matplotlib.backends.backend_pdf"
-        ), PdfPages(plot_path) as pdf:
+        with silent_loggers("matplotlib.font_manager", "matplotlib.backends.backend_pdf"), PdfPages(
+            plot_path
+        ) as pdf:
             for plane in ["xy", "xz", "yz"]:
                 plt.figure()
                 ax = plt.gca()
@@ -241,7 +246,7 @@ def make_collage(
     top_panel_shift += layer_boundaries[-1]
 
     mtypes = sorted(df.mtype.unique())
-    with disable_loggers("matplotlib.font_manager", "matplotlib.backends.backend_pdf"), PdfPages(
+    with silent_loggers("matplotlib.font_manager", "matplotlib.backends.backend_pdf"), PdfPages(
         data_dir.parent.parent / collage_path
     ) as pdf:
         for mtype in tqdm(mtypes):
@@ -253,7 +258,7 @@ def make_collage(
                 for shift, morph_name in enumerate(batch):
                     try:
                         layer_pos = layer_centers[int(mtype[1]) - 1]
-                    except (TypeError, IndexError):
+                    except (TypeError, IndexError, ValueError):
                         layer_pos = layer_centers.mean()
                     neuron = load_morphology(_df.loc[morph_name, "morph_path"])
 
@@ -289,16 +294,18 @@ def make_collage(
                         realistic_diameters=False,
                     )
                     ax.text(
-                        shift * separation - separation / 2.0,
+                        shift * separation,
                         layer_boundaries[0] - 100,
                         morph_name,
                         fontsize="x-small",
                         rotation=45,
+                        horizontalalignment="center",
                     )
 
                 for lb in layer_boundaries:
                     ax.axhline(lb, color="r", ls="--", alpha=0.3)
 
+                ax.autoscale_view()
                 ax.set_rasterized(rasterized)
                 ax.set_title(f"{mtype}, page {page + 1} / {len(name_batches)}")
                 ax.set_ylim(layer_boundaries[0] - 150, top_panel_shift + 100)
@@ -323,7 +330,7 @@ def _create_db_row(_data, zero_diameter_path, unravel_path, repair_path, extensi
     index, data = _data
     m = MorphInfo(
         name=data["morph_name"],
-        mtype=data["mtype"],
+        mtype=data["mtype"] if isinstance(data["mtype"], str) else "",
         layer=int(data["layer"]),
         use_dendrite=data["has_basal"],
         use_axon=data["has_axon"],
@@ -372,7 +379,14 @@ def set_layer_column(df):
 def add_duplicated_layers(df):
     """Duplicate entries if layer name has mixed layers, i.e. L23_PC."""
     for mtype in df.mtype.unique():
-        layer = mtype.split("_")[0][1:]
+        if pd.isnull(mtype):
+            layer = "0"
+        else:
+            split = mtype.split("_")
+            if len(split) > 0 and len(split[0]) > 0:
+                layer = [0][1:]
+            else:
+                layer = "0"
         if len(layer) > 1:
             _df = df[df.mtype == mtype]
             _df.layer = int(layer[1])
@@ -381,7 +395,14 @@ def add_duplicated_layers(df):
 
 
 def make_release(
-    df, _, zero_diameter_path, unravel_path, repair_path, extensions, duplicate_layers=True
+    df,
+    _,
+    release_path,
+    zero_diameter_path,
+    unravel_path,
+    repair_path,
+    extensions,
+    duplicate_layers=True,
 ):
     """Make morphology release."""
     set_layer_column(df)
@@ -390,20 +411,22 @@ def make_release(
     if duplicate_layers:
         df_tmp = add_duplicated_layers(df_tmp)
 
+    release_path = Path(release_path or "")
+
     for extension in extensions:
         _zero_diameter_path = None
         if zero_diameter_path is not None:
-            _zero_diameter_path = Path(f"{zero_diameter_path}-{extension[1:]}")
+            _zero_diameter_path = release_path / f"{zero_diameter_path}/{extension[1:]}"
             _zero_diameter_path.mkdir(exist_ok=True, parents=True)
 
         _unravel_path = None
         if unravel_path is not None:
-            _unravel_path = Path(f"{unravel_path}-{extension[1:]}")
+            _unravel_path = release_path / f"{unravel_path}/{extension[1:]}"
             _unravel_path.mkdir(exist_ok=True, parents=True)
 
         _repair_path = None
         if repair_path is not None:
-            _repair_path = Path(f"{repair_path}-{extension[1:]}")
+            _repair_path = release_path / f"{repair_path}/{extension[1:]}"
             _repair_path.mkdir(exist_ok=True, parents=True)
 
         __create_db_row = partial(
