@@ -6,22 +6,22 @@ import luigi
 import numpy as np
 import pytest
 from dir_content_diff import assert_equal_trees
+from dir_content_diff import compare_files
+from dir_content_diff.base_comparators import IniComparator
+from dir_content_diff.base_comparators import JsonComparator
 
+from morphology_workflows.tasks import cli
 from morphology_workflows.tasks import workflows
 
 from . import clean_exception
 
 
 @pytest.fixture()
-def example_1(tmp_working_dir, examples_dir):
+def example_1(tmp_working_dir, examples_test_dir):
     """Setup the working directory."""
-    shutil.copyfile(examples_dir / "logging.conf", tmp_working_dir / "logging.conf")
-    shutil.copyfile(examples_dir / "luigi.cfg", tmp_working_dir / "luigi.cfg")
-    shutil.copyfile(examples_dir / "dataset.csv", tmp_working_dir / "dataset.csv")
-    shutil.copyfile(examples_dir / "builder_recipe.xml", tmp_working_dir / "builder_recipe.xml")
-    shutil.copyfile(examples_dir / "placement_rules.xml", tmp_working_dir / "placement_rules.xml")
-    shutil.copyfile(examples_dir / "transform_rules.xml", tmp_working_dir / "transform_rules.xml")
-    shutil.copytree(examples_dir / "morphologies", tmp_working_dir / "morphologies")
+    shutil.copyfile(examples_test_dir / "dataset.csv", tmp_working_dir / "dataset.csv")
+    shutil.copytree(examples_test_dir / "morphologies", tmp_working_dir / "morphologies")
+    cli.main(["Initialize"])
 
     # Set current config in luigi
     luigi_config = luigi.configuration.get_config()
@@ -447,3 +447,29 @@ def test_example_1(example_1, data_dir):
     assert_equal_trees(
         repair_expected_dir, example_1 / "out_repaired", specific_args=repaired_specific_args
     )
+
+
+def test_example_generation(tmp_working_dir, examples_dir):
+    """Test that the example is the same as the one generated by the Initialize workflow."""
+    db_source = "NeuroMorpho"
+    cli.main(["Initialize", "--source-database", db_source])
+
+    assert (tmp_working_dir / "logging.conf").exists()
+    assert (tmp_working_dir / "luigi.cfg").exists()
+    assert (tmp_working_dir / "neuromorpho_config.json").exists()
+
+    compare_files(
+        tmp_working_dir / "logging.conf",
+        examples_dir / "logging.conf",
+        IniComparator(),
+    )
+    compare_files(
+        tmp_working_dir / "luigi.cfg",
+        examples_dir / "luigi.cfg",
+        IniComparator(),
+    )
+    compare_files(
+        tmp_working_dir / f"{db_source.lower()}_config.json",
+        examples_dir / f"{db_source.lower()}_config.json",
+        JsonComparator(),
+    )
